DbTransaction class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
Statement statement, void successCallback(DbTransaction tx, List< Row> res), [void errorCallback(Object error)?]) → void -
run(
Statement statement, void successCallback(DbTransaction tx, RunResult result)?, [void errorCallback(Object error)?]) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited